clear
clc
rng(123);

%%%%%%%%%%%%%%%%%%%%%%%% Set K-Means Discretization %%%%%%%%%%%%%%%%%%%%%%%
M=35;
disp(' ');
disp('M = ');
disp(M);

%%%%%%%%%%%%%%%%%%%%%%%%%% Set MTR Options %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%MTR stands for the 'Marginal Treatment Response' Assumption 
%
%NOTE: To set the MTR assumption, enter a negative value for "opts_val" to 
%set for P(Y1>Y0)<=-opts_val, and enter a positive value to set 
% P(Y1>Y0)>=opts_val

opts_val=0.95; 

disp(' ');
opts='MTR';
disp(opts_val);
disp(' ');

%%%%%%%%%%%%%%%%%%%% Import Data and set Variables %%%%%%%%%%%%%%%%%%%%%%%%

%Import STAR Dataset
star = csv2mat_numeric('star_original.out'); %Data contains hh_id index

%Set Outcome Variable (Y1 = grade 3 outcomes, Y2 = grade 8 outcomes)
Y=star.Y1;

%Set Treatment Variable (D4 = small class K - 3)
D=star.D4;

%Set Instrument (Z = assigned to small classroom in kindergarten)
Z=star.Z;

%Bin outcome variable according to K-means discretization set in line 7
[idx,C] = kmeans(Y,M);
Y=C(idx);
[~, ~, Y] = unique(Y);
Y=Y/M*100;

n=length(Y);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%% Compute Bounds %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%   Joint Probability Bounds     %%%%%%%%%%%%%%%%%%%%%%%%

[ lower, upper, ~, ~, ~] = r17_parameters('jp', Y,D,Z ,opts,opts_val );

disp('---------------------------------')
disp(' ')
disp('Joint Probability (Y0<=median, Y1>median): ')
joint_prob=[lower,upper];
disp(joint_prob);

%%%%%%%%%%%%%%%%%%% Average Treatment Effect Bounds %%%%%%%%%%%%%%%%%%%%%%%

[ lower, upper, ~, ~,~] = r17_parameters('ate',Y,D,Z ,opts,opts_val );

disp('---------------------------------')
disp(' ')
disp('Average Treatment Effect Bounds: ')
ate=[lower,upper];
disp(ate);
 
%%%%%%%%%%%%%%%%%%%%%%% Voting Criterion Bounds %%%%%%%%%%%%%%%%%%%%%%%%%%%

[ lower, upper,~,~,~ ] = r17_parameters('vc',Y,D,Z ,opts,opts_val );

disp('---------------------------------')
disp(' ')
disp('Voting Criterion Bounds: ')
voting_crit=[lower,upper];
disp(voting_crit);

%%%%%%%%%%%%%%%%%%%%% Conditional Probability Bounds %%%%%%%%%%%%%%%%%%%%%%

[ lower, upper,~,~,~ ] = r17_parameters('cp',Y,D,Z ,opts,opts_val );

disp('---------------------------------')
disp(' ')
disp('Conditional Probability (Y1>med | Y0<=med): ')
cond_prob=[lower,upper];
disp(cond_prob);

%%%%%%%%%%%%%%%%%%%%%%%%%%%% Marginal Bounds %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[ lower, upper,~,~,~] = r17_parameters('mp',Y,D,Z,opts,opts_val );

disp('---------------------------------')
disp(' ')
disp('Marginal Probability (Y0<=Median)')
marginal_prob1=[lower(:,1),upper(:,1)];
disp(marginal_prob1);
disp(' ')
disp('Marginal Probability (Y1>Median)')
marginal_prob2=[lower(:,2),upper(:,2)];
disp(marginal_prob2);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%% Correlation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% [ lower, upper, ~, ~, ~] = r17_parameters('corr',Y,D,Z,opts,opts_val);
% 
% disp('---------------------------------')
% disp(' ')
% disp(' Correlation ')
% correlation=[lower,upper];
% disp(correlation);
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Variance %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% [ lower, upper, ~, ~,~] = r17_parameters('var10',Y,D,Z,opts,opts_val);
% 
% disp('---------------------------------')
% disp(' ')
% disp(' Variance of Y1-Y0')
% variance10=[lower,upper];
% disp(variance10);